#
# Unit Tests
#

import os, sys
if __name__ == '__main__':
    execfile(os.path.join(sys.path[0], 'framework.py'))

from Products.PloneTestCase import PloneTestCase

# CHANGE 'DIYPloneStyle' to your product name in the following lines
from Products.DIYPloneStyle.config import *
from Products.DIYPloneStyle.Extensions.utils import getSkinsFolderNames
PROJECTNAME = 'DIYPloneStyle'

PloneTestCase.installProduct(PROJECTNAME)
PloneTestCase.setupPloneSite(products=[PROJECTNAME])

class testSkinsTool(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.tool = getattr(self.portal, 'portal_skins')

    def testSkinSelectionCreated(self):
        self.failUnless(SKINNAME in self.tool.getSkinSelections())

    def testSkinPaths(self):
        foldernames = getSkinsFolderNames(GLOBALS)
        for selection, layers in self.tool.getSkinPaths():
            for foldername in foldernames:
                if selection == SKINNAME:
                    self.failUnless(foldername in layers)
                else:
                    self.failIf(foldername in layers)

    def testSkinSelection(self):
        if SELECTSKIN:
            self.assertEqual(self.tool.getDefaultSkin(), SKINNAME)

    def testSkinFlexibility(self):
        self.assertEqual(self.tool.getAllowAny(), ALLOWSELECTION)

    def testCookiePersistance(self):
        self.assertEqual(self.tool.getCookiePersistence(), PERSISTENTCOOKIE)

class testResourceRegistrations(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.csstool = getattr(self.portal, 'portal_css')
        self.jstool  = getattr(self.portal, 'portal_javascripts')

    def testStylesheetsInstalled(self):
        stylesheetids = self.csstool.getResourceIds()
        for css in STYLESHEETS:
            self.failUnless(css['id'] in stylesheetids)

    def testStylesheetProperties(self):
        for css in STYLESHEETS:
            res = self.csstool.getResource(css['id'])
            if css.has_key('enabled'):
                self.assertEqual(res.getEnabled(), css['enabled'])
            if css.has_key('title'):
                self.assertEqual(res.getTitle(), css['title'])
            if css.has_key('expression'):
                self.assertEqual(res.getExpression(), css['expression'])
            if css.has_key('cookable'):
                self.assertEqual(res.getCookable(), css['cookable'])
            if css.has_key('media'):
                self.assertEqual(res.getMedia(), css['media'])
            if css.has_key('rel'):
                self.assertEqual(res.getRel(), css['rel'])
            if css.has_key('rendering'):
                self.assertEqual(res.getRendering(), css['rendering'])

    def testJavascriptsInstalled(self):
        javascriptids = self.jstool.getResourceIds()
        for js in JAVASCRIPTS:
            self.failUnless(js['id'] in javascriptids)

    def testMemberStylesheetProperties(self):
        for js in JAVASCRIPTS:
            res = self.jstool.getResource(js)
            if css.has_key('enabled'):
                self.assertEqual(res.getEnabled(), p['enabled'])
            if css.has_key('expression'):
                self.assertEqual(res.getExpression(), p['expression'])
            if css.has_key('cookable'):
                self.assertEqual(res.getCookable(), p['cookable'])
            if css.has_key('inline'):
                self.assertEqual(res.getInline(), p['inline'])


class testUninstall(PloneTestCase.PloneTestCase):

    def afterSetUp(self):
        self.qitool    = getattr(self.portal, 'portal_quickinstaller')
        self.skinstool = getattr(self.portal, 'portal_skins')
        self.csstool   = getattr(self.portal, 'portal_css')
        self.jstool    = getattr(self.portal, 'portal_javascripts')
        self.qitool.uninstallProducts(products=[PROJECTNAME])

    def testProductUninstalled(self):
        self.failIf(self.qitool.isProductInstalled(PROJECTNAME))

    def testSkinSelectionDeleted(self):
        self.failIf(SKINNAME in self.skinstool.getSkinSelections())

    def testDefaultSkinChanged(self):
        if FULLRESET:
            self.assertEqual(self.skinstool.getDefaultSkin(), 'Plone Default')
        else:
            self.assertEqual(self.skinstool.getDefaultSkin(), BASESKIN)

    def testResetSkinFlexibility(self):
        if FULLRESET:
            self.failIf(self.skinstool.getAllowAny())
        else:
            self.assertEqual(self.skinstool.getAllowAny(), ALLOWSELECTION)

    def testResetCookiePersistance(self):
        if FULLRESET:
            self.failIf(self.skinstool.getCookiePersistence())
        else:
            self.assertEqual(self.skinstool.getCookiePersistence(),
                             PERSISTENTCOOKIE)

    def testStylesheetsUninstalled(self):
        stylesheetids = self.csstool.getResourceIds()
        for css in STYLESHEETS:
            self.failIf(css['id'] in stylesheetids)

    def testJavascriptsUninstalled(self):
        javascriptids = self.jstool.getResourceIds()
        for js in JAVASCRIPTS:
            self.failIf(js['id'] in javascriptids)

if __name__ == '__main__':
    framework()
else:
    import unittest
    def test_suite():
        suite = unittest.TestSuite()
        suite.addTest(unittest.makeSuite(testSkinsTool))
        suite.addTest(unittest.makeSuite(testResourceRegistrations))
        suite.addTest(unittest.makeSuite(testUninstall))
        return suite
